# rag-colls

Simple and easy to use, production-ready advanced RAG techniques.

<div align="center">

![Downloads](https://img.shields.io/pypi/dm/rag_colls)  ![License](https://img.shields.io/badge/license-MIT-green)

</div>

## :rocket: Upcoming

We are currently working on these projects and will be updated in the near future.

| RAG Tech | Link  |
|:----------:|:----------:|
| ContextualRAG | [Blog](https://www.anthropic.com/news/contextual-retrieval) |
| RAFT | [Blog](https://techcommunity.microsoft.com/blog/aiplatformblog/raft-a-new-way-to-teach-llms-to-be-better-at-rag/4084674), [Paper](https://arxiv.org/pdf/2403.10131)|
| RAG-RL |[Paper](https://arxiv.org/pdf/2503.12759)|

## :wrench: Installation

**1.** You can easily install it from pypi:

```bash
pip install rag-colls
```

## :tada: Quick start

Please refer to [example](./examples) for more information.

## :book: Notebooks

We have provided some notebooks for example usage.

| RAG Tech | Link  | Collab |
|:----------:|:----------:|:----------:|
| BasicRAG | [BasicRAG](./rag_colls/rags/basic_rag) | [Collab](https://colab.research.google.com/drive/19hzGSQqx-LIsSbnNkV71ipRAIiFingvP)|

## Contributors

<table>
<tr>
    <td align="center" style="word-wrap: break-word; width: 150.0; height: 150.0">
        <a href=https://github.com/hienhayho>
            <img src=https://avatars.githubusercontent.com/u/115549171?v=4 width="100;"  style="border-radius:50%;align-items:center;justify-content:center;overflow:hidden;padding-top:10px" alt=Ho Trong Hien/>
            <br />
            <sub style="font-size:14px"><b>Ho Trong Hien</b></sub>
        </a>
    </td>
</tr>
</table>

## :copyright: LICENSE

`rag-colls` is under [MIT LICENSE.](./LICENSE)
